@@ -8,7 +8,7 @@ import multiprocessing as mp
 import numpy as np
 from scipy.optimize import OptimizeResult
 from fcmaes.testfun import Wrapper, Rosen, Rastrigin, Eggholder
-from fcmaes import cmaes, de, cmaescpp, gcldecpp, retry, advretry
+from fcmaes import cmaes, de, decpp, cmaescpp, gcldecpp, retry, advretry
 
 def test_rastrigin_python():
     popsize = 100
@@ -119,41 +119,15 @@ def test_rosen_parallel():
         wrapper = Wrapper(testfun.fun, dim)
         ret = cmaes.minimize(wrapper.eval, testfun.bounds, input_sigma = sdevs, 
                        max_evaluations = max_eval, 
-                       popsize=popsize, workers = mp.cpu_count())
+                       popsize=popsize, workers = popsize)
         if limit > ret.fun:
             break
        
     assert(limit > ret.fun) # optimization target not reached
     assert(max_eval + popsize >= ret.nfev) # too much function calls
     assert(max_eval // popsize + 2 > ret.nit) # too much iterations
-    assert(ret.nfev == wrapper.get_count()) # wrong number of function calls returned
     assert(almost_equal(ret.x, wrapper.get_best_x())) # wrong best X returned
-    assert(ret.fun == wrapper.get_best_y()) # wrong best y returned
-
-def test_rosen_delayed():
-    popsize = 8
-    dim = 2
-    testfun = Rosen(dim)
-    sdevs = [1.0]*dim
-    max_eval = 10000
-    
-    limit = 0.00001   
-    for _ in range(5):
-        wrapper = Wrapper(testfun.fun, dim)
-        ret = cmaes.minimize(wrapper.eval, testfun.bounds, None, input_sigma = sdevs, 
-                       max_evaluations = max_eval, 
-                       popsize=popsize, workers = popsize, delayed_update=True)
-        if limit > ret.fun:
-            break
-       
-    assert(limit > ret.fun) # optimization target not reached
-    assert(max_eval + popsize >= ret.nfev) # too much function calls
-    assert(max_eval // popsize + 2 > ret.nit) # too much iterations
-#     assert(ret.nfev == wrapper.get_count()) # wrong number of function calls returned
-#     assert(almost_equal(ret.x, wrapper.get_best_x())) # wrong best X returned
-#     assert(almost_equal(ret.fun, wrapper.get_best_y())) # wrong best y returned
-
-test_rosen_delayed()
+    assert(almost_equal(ret.fun, wrapper.get_best_y(), eps=1E-1)) # wrong best y returned
 
 def test_rosen_cpp_parallel():
     popsize = 8
@@ -167,16 +141,15 @@ def test_rosen_cpp_parallel():
         wrapper = Wrapper(testfun.fun, dim)
         ret = cmaescpp.minimize(wrapper.eval, testfun.bounds, input_sigma = sdevs, 
                        max_evaluations = max_eval, 
-                       popsize=popsize, workers = mp.cpu_count())
+                       popsize=popsize, workers = popsize)
         if limit > ret.fun:
             break
        
     assert(limit > ret.fun) # optimization target not reached
     assert(max_eval + popsize >= ret.nfev) # too much function calls
     assert(max_eval // popsize + 2 > ret.nit) # too much iterations
-    assert(ret.nfev == wrapper.get_count()) # wrong number of function calls returned
     assert(almost_equal(ret.x, wrapper.get_best_x())) # wrong best X returned
-    assert(ret.fun == wrapper.get_best_y()) # wrong best y returned
+    assert(almost_equal(ret.fun, wrapper.get_best_y(), eps = 1E-1)) # wrong best y returned
 
 def test_rosen_gclde_parallel():
     popsize = 8
@@ -220,7 +193,7 @@ def test_rosen_de():
     assert(almost_equal(ret.x, wrapper.get_best_x())) # wrong best X returned
     assert(ret.fun == wrapper.get_best_y()) # wrong best y returned
 
-def test_rosen_de_delayed():
+def test_rosen_de_parallel():
     popsize = 8
     dim = 2
     testfun = Rosen(dim)
@@ -239,7 +212,7 @@ def test_rosen_de_delayed():
     assert(max_eval // popsize + 2 > ret.nit) # too much iterations
     assert(ret.nfev == wrapper.get_count()) # wrong number of function calls returned
 #     assert(almost_equal(ret.x, wrapper.get_best_x())) # wrong best X returned
-#     assert(almost_equal(ret.fun, wrapper.get_best_y())) # wrong best y returned
+    assert(almost_equal(ret.fun, wrapper.get_best_y(), eps = 1E-1)) # wrong best y returned
 
 def test_rosen_ask_tell_de():    
     popsize = 8
@@ -266,7 +239,49 @@ def test_rosen_ask_tell_de():
     assert(max_eval + 2*popsize >= ret.nfev) # too much function calls
     assert(max_eval / popsize + 2 > ret.nit) # too much iterations
 #     assert(almost_equal(ret.x, wrapper.get_best_x())) # wrong best X returned
-#     assert(ret.fun == wrapper.get_best_y()) # wrong best y returned
+    assert(almost_equal(ret.fun, wrapper.get_best_y(), eps = 1E-1)) # wrong best y returned
+
+def test_rosen_decpp():
+    popsize = 8
+    dim = 2
+    testfun = Rosen(dim)
+    max_eval = 10000    
+    limit = 0.00001   
+    for _ in range(5):
+        wrapper = Wrapper(testfun.fun, dim)
+        ret = decpp.minimize(wrapper.eval, dim, testfun.bounds,
+                       max_evaluations = max_eval, 
+                       popsize=popsize, workers = None)
+        if limit > ret.fun:
+            break
+       
+    assert(limit > ret.fun) # optimization target not reached
+    assert(max_eval + 2*popsize >= ret.nfev) # too much function calls
+    assert(max_eval // popsize + 2 > ret.nit) # too much iterations
+    assert(ret.nfev == wrapper.get_count()) # wrong number of function calls returned
+    assert(almost_equal(ret.x, wrapper.get_best_x())) # wrong best X returned
+    assert(almost_equal(ret.fun, wrapper.get_best_y())) # wrong best y returned
+
+def test_rosen_decpp_parallel():
+    popsize = 8
+    dim = 2
+    testfun = Rosen(dim)
+    max_eval = 10000    
+    limit = 0.01   
+    for _ in range(5):
+        wrapper = Wrapper(testfun.fun, dim)
+        ret = decpp.minimize(wrapper.eval, dim, testfun.bounds,
+                       max_evaluations = max_eval, 
+                       popsize=popsize, workers = popsize)
+        if limit > ret.fun:
+            break
+       
+    assert(limit > ret.fun) # optimization target not reached
+    assert(max_eval + popsize >= ret.nfev) # too much function calls
+    assert(max_eval // popsize + 2 > ret.nit) # too much iterations
+    assert(ret.nfev == wrapper.get_count()) # wrong number of function calls returned
+    assert(almost_equal(ret.x, wrapper.get_best_x(), eps = 10)) # wrong best X returned
+    assert(almost_equal(ret.fun, wrapper.get_best_y(), eps = 1E-1)) # wrong best y returned
 
 def test_eggholder_python():
     popsize = 1000
@@ -324,13 +339,12 @@ def test_eggholder_advanced_retry():
     assert(almost_equal(ret.x, wrapper.get_best_x())) # wrong best X returned
     assert(almost_equal(ret.fun, wrapper.get_best_y())) # wrong best y returned
  
-def almost_equal(X1, X2):
+def almost_equal(X1, X2, eps = 1E-5):
     if np.isscalar(X1):
         X1 = [X1]
         X2 = [X2]
     if len(X1) != len(X2):
         return False
-    eps = 1E-5
     for i in range(len(X1)):
         a = X1[i]
         b = X2[i]
